{# doc Render a hidden input field for a field. #}
{# def widget: Annotated[fastlife.adapters.jinjax.widgets.hidden.HiddenWidget, "widget to display."] #}
<Hidden :name="widget.name" :value="widget.value" :id="widget.id" />
