{# def
    id=None,
    title=None,
    mode: Literal["micro","mini","outline","solid"] = "solid"
#}

{% if mode == "micro"%}<icons.micro.ArrowLongUp :id="id" :class="attrs.class or ''" :title="title" />
{% elif mode == "mini"%}<icons.mini.ArrowLongUp :id="id" :class="attrs.class or ''" :title="title" />
{% elif mode == "outline"%}<icons.outline.ArrowLongUp :id="id" :class="attrs.class or ''" :title="title" />
{% elif mode == "solid"%}<icons.solid.ArrowLongUp :id="id" :class="attrs.class or ''" :title="title" />
{%endif%}
