{# def id=None, title=None #}

<svg xmlns="http://www.w3.org/2000/svg" {% if id %}id="{{id}}" {%endif%}class="{{attrs.class or ''}}" viewBox="0 0 24 24" fill="currentColor" aria-hidden="true">
  <path fill-rule="evenodd" d="M15.256 3.042a.75.75 0 0 1 .449.962l-6 16.5a.75.75 0 1 1-1.41-.513l6-16.5a.75.75 0 0 1 .961-.449Z" clip-rule="evenodd">{% if title %}<title>{{title}}</title>{% endif %}</path>
</svg>
